@@ -198,9 +198,8 @@ test_parsability (void)
 		{ "file:///tmp/file_doesnt_exist.wmv", FALSE, FALSE },
 		{ "http://live.hujjat.org:7860/main", FALSE, TRUE },
 		{ "http://www.comedycentral.com/sitewide/media_player/videoswitcher.jhtml?showid=934&category=/shows/the_daily_show/videos/headlines&sec=videoId%3D36032%3BvideoFeatureId%3D%3BpoppedFrom%3D_shows_the_daily_show_index.jhtml%3BisIE%3Dfalse%3BisPC%3Dtrue%3Bpagename%3Dmedia_player%3Bzyg%3D%27%2Bif_nt_zyg%2B%27%3Bspan%3D%27%2Bif_nt_span%2B%27%3Bdemo%3D%27%2Bif_nt_demo%2B%27%3Bbps%3D%27%2Bif_nt_bandwidth%2B%27%3Bgateway%3Dshows%3Bsection_1%3Dthe_daily_show%3Bsection_2%3Dvideos%3Bsection_3%3Dheadlines%3Bzyg%3D%27%2Bif_nt_zyg%2B%27%3Bspan%3D%27%2Bif_nt_span%2B%27%3Bdemo%3D%27%2Bif_nt_demo%2B%27%3Bera%3D%27%2Bif_nt_era%2B%27%3Bbps%3D%27%2Bif_nt_bandwidth%2B%27%3Bfla%3D%27%2Bif_nt_Flash%2B%27&itemid=36032&clip=com/dailyshow/headlines/10156_headline.wmv&mswmext=.asx", TRUE, TRUE },
-		{ TEST_SRCDIR "HackerMedley", TRUE, FALSE }, /* From https://bugzilla.redhat.com/show_bug.cgi?id=582850 and http://feeds.feedburner.com/HackerMedley */
 		{ NULL,  FALSE, FALSE }
-	};
+	};	
 
 	/* Loop through the list, downloading the URIs and checking for parsability */
 	for (i = 0; files[i].uri != NULL; ++i) {
@@ -444,28 +443,6 @@ test_parsing_xml_mixed_cdata (void)
 	g_free (uri);
 }
 
-static void
-test_parsing_not_asx_playlist (void)
-{
-	char *uri;
-	g_test_bug ("610471");
-	/* File from https://bugzilla.gnome.org/show_bug.cgi?id=610471#c0 */
-	uri = get_relative_uri (TEST_SRCDIR "asf-with-asx-suffix.asx");
-	g_assert (simple_parser_test (uri) == TOTEM_PL_PARSER_RESULT_SUCCESS);
-	g_free (uri);
-}
-
-static void
-test_parsing_not_really_php (void)
-{
-	char *uri;
-	g_test_bug ("590722");
-	/* File from http://startwars.org/dump/remote_xspf.php */
-	uri = get_relative_uri (TEST_SRCDIR "remote_xspf.php");
-	g_assert (simple_parser_test (uri) == TOTEM_PL_PARSER_RESULT_SUCCESS);
-	g_free (uri);
-}
-
 #define MAX_DESCRIPTION_LEN 128
 #define DATE_BUFSIZE 512
 #define PRINT_DATE_FORMAT "%Y-%m-%dT%H:%M:%SZ"
@@ -631,8 +608,6 @@ main (int argc, char *argv[])
 		g_test_add_func ("/parser/parsing/single_line_rtsptext", test_parsing_rtsp_text);
 		g_test_add_func ("/parser/parsing/live_streaming", test_parsing_live_streaming);
 		g_test_add_func ("/parser/parsing/xml_mixed_cdata", test_parsing_xml_mixed_cdata);
-		g_test_add_func ("/parser/parsing/not_asx_playlist", test_parsing_not_asx_playlist);
-		g_test_add_func ("/parser/parsing/not_really_php", test_parsing_not_really_php);
 
 		return g_test_run ();
 	}
